PyBaccarat: tests.test_shoe Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes | Functions
tests.test_shoe Namespace Reference

Unit test for the Shoe class. More...

## Classes
class | TestShoe

## Functions
def | delete_file (filespec)
| Delete a file if it exists. More...

## Detailed Description

Unit test for the Shoe class.

To execute the unit test from base dir location, enter:

cd pybaccarat_base
python tests\test_shoe.py [-v]

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om

## Function Documentation

## ◆ delete_file()

def tests.test_shoe.delete_file | ( |  | filespec | ) |

Delete a file if it exists.

Parameters

  filespec | file to delete